==> sapdb-all-linux-32bit-i386-7_3_0_48.tgz: env/QP.py <==
#
# =====================================================
# @(#) QP                        7.3        1999-07-29
# =====================================================
# Changes in  7.3:
#
#    ========== licence begin LGPL
#    Copyright (C) 2000 SAP AG
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    ========== licence end
#


from installib import *

def install (session,options):
    """Installing tables for SQL Studio
    """

    include (session, options, 'AS')

    repmanCmd (session, 'INSTALLATION ON')

    repmanCmd (session, 'AUTOCOMMIT OFF')

    #ADIS #1001953/1002033
    requireSysdba (session)

    #----------------------------------------------------------------------------
    # Create table for the object management
    #----------------------------------------------------------------------------
    if existsTable (session, "SYSQP_ALL_OBJECTS"):

        sqlOK (session, "UPDATE SYSQP_ALL_OBJECTS SET OBJTYPE = '1' WHERE OBJTYPE = 'QP Statement'")
        sqlOK (session, "UPDATE SYSQP_ALL_OBJECTS SET OBJTYPE = '2' WHERE OBJTYPE = 'QP Query'")
        sqlOK (session, "UPDATE SYSQP_ALL_OBJECTS SET OBJTYPE = '3' WHERE OBJTYPE = 'QP WordLink'")
        sqlOK (session, "UPDATE SYSQP_ALL_OBJECTS SET OBJTYPE = '4' WHERE OBJTYPE = 'QP ExcelLink'")

        if not sqlOK (session, """SELECT OWNER
                FROM SYSDD.COLUMNS
                WHERE OWNER = USER
                AND TABLENAME = 'SYSQP_ALL_OBJECTS'
                AND COLUMNNAME = 'OWNER'
                AND LEN > 18"""):
            sqlOK (session, "DELETE SYSQP_ALL_OBJECTS WHERE OBJTYPE = '2'")
            sqlOK (session, "DELETE SYSQP_ALL_OBJECTS WHERE OBJTYPE = '3'")
            sqlOK (session, "DELETE SYSQP_ALL_OBJECTS WHERE OBJTYPE = '4'")

        stopIfSqlNotOK (session, """ALTER TABLE SYSQP_ALL_OBJECTS
            MODIFY (OWNER SYSID, OBJTYPE CHAR(2), NAME CHAR(150))""")

        #  ADIS ErrorId Begin: 1000740
        if not sqlOK (session, """SELECT OWNER
                FROM SYSDD.COLUMNS
                WHERE OWNER = USER
                AND TABLENAME = 'SYSQP_ALL_OBJECTS'
                AND COLUMNNAME = 'SHARECOUNT'"""):

            stopIfSqlNotOK (session, "ALTER TABLE SYSQP_ALL_OBJECTS ADD SHARECOUNT CHAR(5) ASCII")
            stopIfSqlNotOK (session, "ALTER TABLE SYSQP_ALL_OBJECTS MODIFY (SHARECOUNT CHAR(5) ASCII DEFAULT '0'")
        #  ADIS ErrorId End: 1000740


        #   ADDITIONAL ATTRIBUTES FOR STORED OBJECTS
        if not sqlOK (session, """SELECT OWNER
                FROM SYSDD.COLUMNS
                WHERE OWNER = USER
                AND TABLENAME = 'SYSQP_ALL_OBJECTS'
                AND COLUMNNAME = 'ATTRIBUTES'"""):
            stopIfSqlNotOK (session, "ALTER TABLE SYSQP_ALL_OBJECTS ADD ATTRIBUTES VARCHAR(512) BYTE")
            stopIfSqlNotOK (session, "ALTER TABLE SYSQP_ALL_OBJECTS MODIFY (ATTRIBUTES VARCHAR(512) BYTE DEFAULT X'000100010001')")
        #   End: ADDITIONAL ATTRIBUTES FOR STORED OBJECTS


        #   6.2.10
        stopIfSqlNotOK (session, "ALTER TABLE SYSQP_ALL_OBJECTS ALTER PRIMARY KEY (ID)")

        if not sqlOK (session, "SELECT * FROM SYSDD.INDEXES WHERE INDEXNAME = 'SYSQP_ALL_OBJECTS_INDEXES'"):
            sqlOK (session, "CREATE UNIQUE INDEX SYSQP_ALL_OBJECTS_INDEXES ON SYSQP_ALL_OBJECTS (OWNER,OBJTYPE,NAME)")


    else:
        #   ADIS ErrorId Begin: 1000740
        #   Begin: QP-6.2.9
        stopIfSqlNotOK (session, """
            CREATE TABLE SYSQP_ALL_OBJECTS  (
                    OWNER       SYSID                           ,
                    OBJTYPE     CHAR(2) ASCII                   ,
                    NAME        CHAR(150)                       ,
                    ID          CHAR(8)     BYTE DEFAULT STAMP  ,
                    OBJDESC     LONG        BYTE                ,
                    SHARECOUNT  CHAR(5) ASCII  DEFAULT '0'      ,
                    ATTRIBUTES  VARCHAR(512) BYTE               ,
                    CONSTRAINT SYSQP_ALL_OBJECTS_PK PRIMARY KEY (ID) )
            INTERNAL""")
        #   ADIS ErrorId End: 1000740
        #   End: QP-6.2.9

        sqlOK (session, "CREATE UNIQUE INDEX SYSQP_ALL_OBJECTS_INDEXES ON SYSQP_ALL_OBJECTS (OWNER,OBJTYPE,NAME)")


    #----------------------------------------------------------------------------
    # Create table for the user profiles entries
    #----------------------------------------------------------------------------

    dropTable (session, "SYSQP_INI")

    if sqlOK (session, "IF $RC (SELECT * FROM SYSDD.TABLES WHERE TABLENAME ='SYSQP_USER_PROFILES' AND TABLETYPE = 'TABLE'"):
        sqlOK (session, "REVOKE UPDATE, DELETE, INSERT ON SYSQP_USER_PROFILES FROM PUBLIC")
        sqlOK (session, "RENAME TABLE SYSQP_USER_PROFILES TO SYSQP_ALL_USER_PROFILES")


    if not existsTable (session, "SYSQP_ALL_USER_PROFILES"):
        stopIfSqlNotOK (session, """
        CREATE TABLE SYSQP_ALL_USER_PROFILES (
                "UID"       SYSID
                    CONSTRAINT SYSQP_ALL_USER_PROFILES_PK PRIMARY KEY,
                PROFILE     LONG        BYTE ) INTERNAL""")


    #----------------------------------------------------------------------------
    # Create table for the shared objects
    #----------------------------------------------------------------------------


    if existsTable (session, "SYSQP_SHARED_OBJECTS"):

        sqlOK (session, "DELETESYSQP_SHARED_OBJECTS")
        stopIfSqlNotOK (session, "RENAME TABLE  SYSQP_SHARED_OBJECTS TO SYSQP_ALL_SHARED_OBJECTS")
        stopIfSqlNotOK (session, "ALTER TABLE SYSQP_ALL_SHARED_OBJECTS ADD OWNER SYSID")
        stopIfSqlNotOK (session, "ALTER TABLE SYSQP_ALL_SHARED_OBJECTS ALTER PRIMARY KEY (GRANTEE,OWNER,ID)")
        stopIfSqlNotOK (session, "REVOKE UPDATE, DELETE, INSERT ON SYSQP_ALL_SHARED_OBJECTS FROM PUBLIC")
        stopIfSqlNotOK (session, "ALTER TABLE SYSQP_ALL_SHARED_OBJECTS  FOREIGN KEY (ID) REFERENCES SYSQP_ALL_OBJECTS (ID) ON DELETE CASCADE")

    if not existsTable (session, "SYSQP_ALL_SHARED_OBJECTS"):

        stopIfSqlNotOK (session, """
            CREATE TABLE SYSQP_ALL_SHARED_OBJECTS
            (
                GRANTEE         SYSID              ,
                OWNER           SYSID              ,
                ID              CHAR (8  ) BYTE,
                TYPEOFACCESS    FIXED(1  )         ,
                NAME            CHAR(150)          ,
                COMMENT         CHAR (150)         ,
                ENABLED         FIXED(1  ),
                CONSTRAINT SYSQP_ALL_SHARED_OBJECTS_PK PRIMARY KEY(GRANTEE,OWNER,ID),
                FOREIGN KEY (ID) REFERENCES SYSQP_ALL_OBJECTS (ID) ON DELETE CASCADE
            ) INTERNAL""")



    #----------------------------------------------------------------------------
    # Create table for favorites
    #----------------------------------------------------------------------------

    if not existsTable (session, "SYSQP_ALL_FAVORITES"):
        stopIfSqlNotOK (session, """
            CREATE TABLE SYSQP_ALL_FAVORITES
            (
                    FOWNER          SYSID,
                    FITEMOWNER      SYSID,
                    FITEMNAME       CHAR (64)       ,
                    FITEMTYPE       INT             ,
                    FCOMMENT        VARCHAR (512) ASCII,
                    FINFO           VARCHAR (512) BYTE,
                    CONSTRAINT SYSQP_ALL_FAVORITES_PK
                        PRIMARY KEY(FOWNER,FITEMOWNER,FITEMNAME,FITEMTYPE)

            ) INTERNAL""")


    #----------------------------------------------------------------------------
    # Views of the Conversational Component QueryPlus
    #----------------------------------------------------------------------------


    #----------------------------------------------------------------------------
    # Create the view of the object management for each user
    #----------------------------------------------------------------------------

    dropView (session, "SYSQP_MY_OBJECTS")

    # ADIS ErrorId Begin: 1000740
    stopIfSqlNotOK (session, """
        CREATE VIEW SYSQP_MY_OBJECTS AS
            SELECT  OWNER       ,
                    OBJTYPE     ,
                    NAME        ,
                    ID          ,
                    OBJDESC     ,
                    SHARECOUNT  ,
                    ATTRIBUTES
            FROM    SYSQP_ALL_OBJECTS
            WHERE   OWNER = USERGROUP
        WITH CHECK OPTION INTERNAL""")
    # ADIS ErrorId End: 1000740

    #----------------------------------------------------------------------------
    # Create the view for the shared objects, for me from the rest of the world
    #----------------------------------------------------------------------------

    dropView (session, "SYSQP_MY_SHARED_OBJECTS")
    dropView (session, "SYSQP_TO_ME_GRANTED_OBJECTS")

    # ADIS ErrorId: 1000738
    stopIfSqlNotOK (session, """
        CREATE VIEW SYSQP_TO_ME_GRANTED_OBJECTS (OWNER, OBJTYPE, NAME, ID, OBJDESC, SHARECOUNT,ATTRIBUTES) AS
        SELECT  T1.OWNER             ,
                T1.OBJTYPE           ,
                T2.NAME              ,
                T1.ID                ,
                T1.OBJDESC           ,
                T1.SHARECOUNT        ,
                T1.ATTRIBUTES
        FROM    SYSQP_ALL_OBJECTS            T1,
                SYSQP_ALL_SHARED_OBJECTS     T2
        WHERE   (T2.GRANTEE = USERGROUP  OR (T2.GRANTEE = 'PUBLIC' AND T1.OWNER <> USERGROUP))
          AND   T1.ID = T2.ID
          AND   T2.ENABLED = 1
        INTERNAL""")
    # ADIS ErrorId End: 1000738

    #----------------------------------------------------------------------------
    # Create the view of Userprofile
    #----------------------------------------------------------------------------

    dropView (session, "SYSQP_USER_PROFILES")
    stopIfSqlNotOK (session, """
        CREATE VIEW SYSQP_USER_PROFILES AS
            SELECT  "UID"       ,
                    PROFILE
            FROM    SYSQP_ALL_USER_PROFILES
            WHERE   "UID" = USERGROUP
        WITH CHECK OPTION INTERNAL""")


    #----------------------------------------------------------------------------
    # Create the view of 'own shared onjects'
    #----------------------------------------------------------------------------

    dropView (session, "SYSQP_MY_OWN_SHARED_OBJECTS")
    stopIfSqlNotOK (session, """
        CREATE VIEW SYSQP_MY_OWN_SHARED_OBJECTS AS
            SELECT  *
            FROM    SYSQP_ALL_SHARED_OBJECTS
            WHERE   OWNER = USERGROUP
        WITH CHECK OPTION INTERNAL""")


    #----------------------------------------------------------------------------
    # Create the view of 'to me shared onjects'
    #----------------------------------------------------------------------------

    dropView (session, "SYSQP_TO_ME_SHARED_OBJECTS")
    stopIfSqlNotOK (session, """
        CREATE VIEW SYSQP_TO_ME_SHARED_OBJECTS AS
            SELECT  *
            FROM    SYSQP_ALL_SHARED_OBJECTS
            WHERE GRANTEE = USERGROUP OR GRANTEE = 'PUBLIC'
        WITH CHECK OPTION INTERNAL""")


    #----------------------------------------------------------------------------
    # Create the view for favorites
    #----------------------------------------------------------------------------


    dropView (session, "SYSQP_MY_FAVORITES")
    stopIfSqlNotOK (session, """
        CREATE VIEW SYSQP_MY_FAVORITES AS
            SELECT  *
            FROM    SYSQP_ALL_FAVORITES
            WHERE   FOWNER = USERGROUP
        WITH CHECK OPTION INTERNAL""")


    #----------------------------------------------------------------------------
    # Drop old views if exists
    #----------------------------------------------------------------------------

    dropView (session, "SYSQP_SC_OBJECTS")
    dropView (session, "SYSQP_SQ_OBJECTS")
    dropView (session, "SYSQP_SW_OBJECTS")
    dropView (session, "SYSQP_SE_OBJECTS")


    #----------------------------------------------------------------------------
    # Grant for the view SYSQP_MY_OBJECTS
    #----------------------------------------------------------------------------

    stopIfSqlNotOK (session, """
        GRANT   SELECT, UPDATE, DELETE, INSERT
        ON      SYSQP_MY_OBJECTS
        TO      PUBLIC""")

    #----------------------------------------------------------------------------
    # Grant for the view SYSQP_TO_ME_GRANTED_OBJECTS
    #----------------------------------------------------------------------------

    stopIfSqlNotOK (session, """
        GRANT   SELECT
        ON      SYSQP_TO_ME_GRANTED_OBJECTS
        TO      PUBLIC""")

    #----------------------------------------------------------------------------
    # Grant for the view SYSQP_MY_OWN_SHARED_OBJECTS
    #----------------------------------------------------------------------------

    stopIfSqlNotOK (session, """
        GRANT   SELECT, UPDATE, DELETE, INSERT
        ON      SYSQP_MY_OWN_SHARED_OBJECTS
        TO      PUBLIC""")

    #----------------------------------------------------------------------------
    # Grant for the view SYSQP_TO_ME_SHARED_OBJECTS
    #----------------------------------------------------------------------------

    stopIfSqlNotOK (session, """
        GRANT   SELECT, UPDATE, DELETE, INSERT
        ON      SYSQP_TO_ME_SHARED_OBJECTS
        TO      PUBLIC""")

    #----------------------------------------------------------------------------
    # Grant for the view SYSQP_USER_PROFILES
    #----------------------------------------------------------------------------

    stopIfSqlNotOK (session, """
        GRANT   SELECT, UPDATE, DELETE, INSERT
        ON      SYSQP_USER_PROFILES
        TO      PUBLIC""")

    #----------------------------------------------------------------------------
    # Grant for the view SYSQP_MY_FAVORITES
    #----------------------------------------------------------------------------

    stopIfSqlNotOK (session, """
        GRANT   SELECT, UPDATE, DELETE, INSERT
        ON      SYSQP_MY_FAVORITES
        TO      PUBLIC""")


    #----------------------------------------------------------------------------
    # Commit the data definitions
    #----------------------------------------------------------------------------

    repmanCmd (session, 'COMMIT')

    repmanCmd (session, 'INSTALLATION OFF')

    # End of Install


if __name__ == '__main__':
    connectAndInstall (install, install.__doc__)

==> sapdb-all-linux-32bit-i386-7_4_3_32.tgz: env/QP.py <==
#
# =====================================================
# @(#) QP                        7.4        2000-10-13
# =====================================================
# Changes in  7.4:
#
#    ========== licence begin LGPL
#    Copyright (C) 2000 SAP AG
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    ========== licence end
#


from installib import *

def install (session,options):
    """Installing tables for SQL Studio
    """

    include (session, options, 'AS')

    loaderCmd (session, 'INSTALLATION ON')

    loaderCmd (session, 'AUTOCOMMIT OFF')

    #ADIS #1001953/1002033
    requireSysdba (session)

    #----------------------------------------------------------------------------
    # Create table for the user profiles entries
    #----------------------------------------------------------------------------

    if sqlOK (session, "SELECT * FROM SYSDD.TABLES WHERE TABLENAME ='SYSQP_USER_PROFILES' AND TABLETYPE = 'TABLE'"):
        sqlOK (session, "REVOKE UPDATE, DELETE, INSERT ON SYSQP_USER_PROFILES FROM PUBLIC")
        sqlOK (session, "RENAME TABLE SYSQP_USER_PROFILES TO SYSQP_ALL_USER_PROFILES")


    if not existsTable (session, "SYSQP_ALL_USER_PROFILES"):
        stopIfSqlNotOK (session, """
        CREATE TABLE SYSQP_ALL_USER_PROFILES (
                "UID"       SYSID
                 CONSTRAINT SYSQP_ALL_USER_PROFILES_PK PRIMARY KEY,
                 PROFILE     LONG        BYTE ) INTERNAL""")
    else:
        if (options.migrate):
            stopIfSqlNotOK  (session, 'ALTER TABLE SYSQP_ALL_USER_PROFILES MODIFY ("UID" SYSID)')

    #----------------------------------------------------------------------------
    # Create table for favorites
    #----------------------------------------------------------------------------

    if not existsTable (session, "SYSQP_ALL_FAVORITES"):
        stopIfSqlNotOK (session, """
            CREATE TABLE SYSQP_ALL_FAVORITES
            (
                    FOWNER          SYSID,
                    FITEMOWNER      SYSID,
                    FITEMNAME       CHAR (64)       ,
                    FITEMTYPE       INT             ,
                    FCOMMENT        VARCHAR (512) ASCII,
                    FINFO           VARCHAR (512) BYTE,
                    CONSTRAINT SYSQP_ALL_FAVORITES_PK
                        PRIMARY KEY(FOWNER,FITEMOWNER,FITEMNAME,FITEMTYPE)

            ) INTERNAL""")
    else:
        if (options.migrate):
            stopIfSqlNotOK  (session, 'ALTER TABLE SYSQP_ALL_FAVORITES MODIFY (FOWNER     SYSID)')
            stopIfSqlNotOK  (session, 'ALTER TABLE SYSQP_ALL_FAVORITES MODIFY (FITEMOWNER SYSID)')


    #----------------------------------------------------------------------------
    # Views of the Conversational Component QueryPlus
    #----------------------------------------------------------------------------


    #----------------------------------------------------------------------------
    # Create the view of Userprofile
    #----------------------------------------------------------------------------

    dropView (session, "SYSQP_USER_PROFILES")
    stopIfSqlNotOK (session, """
        CREATE VIEW SYSQP_USER_PROFILES AS
            SELECT  "UID"       ,
                    PROFILE
            FROM    SYSQP_ALL_USER_PROFILES
            WHERE   "UID" = USERGROUP
        WITH CHECK OPTION INTERNAL""")


    #----------------------------------------------------------------------------
    # Create the view for favorites
    #----------------------------------------------------------------------------


    dropView (session, "SYSQP_MY_FAVORITES")
    stopIfSqlNotOK (session, """
        CREATE VIEW SYSQP_MY_FAVORITES AS
            SELECT  *
            FROM    SYSQP_ALL_FAVORITES
            WHERE   FOWNER = USERGROUP
        WITH CHECK OPTION INTERNAL""")

    #----------------------------------------------------------------------------
    # Grant for the view SYSQP_USER_PROFILES
    #----------------------------------------------------------------------------

    stopIfSqlNotOK (session, """
        GRANT   SELECT, UPDATE, DELETE, INSERT
        ON      SYSQP_USER_PROFILES
        TO      PUBLIC""")

    #----------------------------------------------------------------------------
    # Grant for the view SYSQP_MY_FAVORITES
    #----------------------------------------------------------------------------

    stopIfSqlNotOK (session, """
        GRANT   SELECT, UPDATE, DELETE, INSERT
        ON      SYSQP_MY_FAVORITES
        TO      PUBLIC""")


    #----------------------------------------------------------------------------
    # Commit the data definitions
    #----------------------------------------------------------------------------

    loaderCmd (session, 'COMMIT')

    loaderCmd (session, 'INSTALLATION OFF')

    # End of Install


if __name__ == '__main__':
    connectAndInstall (install, install.__doc__)
